==> forexflaggr-0.0.4.tar.gz: forexflaggr-0.0.4/forexflaggr/__init__.py <==
from .src.dependencies import (make_subplots, go, px, LinearGAM, lowess, dt, yf, np, warnings)
from .src.pie_chart_recommendation import pie_chart_recommendation
from .src.html_config import Build_HTML_Config
from .src.forex_flaggr import ForexFlaggr
from .src.loess_model import LOESS_Model
from .src.gam_model import GAM_Model

import yaml

# get version from build spec
with open("../build_spec.yml", "r") as f:
    build_spec = yaml.load(f, Loader=yaml.FullLoader)

__version__         = build_spec['__version__']
__author__          = build_spec['__author__']
__email__           = build_spec['__email__']
__credits__         = build_spec['__credits__']



msg =   """
    ______________________________________________________________________________________________________________________________________________
    ______________________________________________________________________________________________________________________________________________

            /$$          /$$$$$$$$                                            /$$$$$$$$ /$$                                        
          /$$$$$$       | $$_____/                                           | $$_____/| $$                                        
         /$$__  $$      | $$     /$$$$$$   /$$$$$$   /$$$$$$  /$$   /$$      | $$      | $$  /$$$$$$   /$$$$$$   /$$$$$$   /$$$$$$ 
        | $$  \__/      | $$$$$ /$$__  $$ /$$__  $$ /$$__  $$|  $$ /$$/      | $$$$$   | $$ |____  $$ /$$__  $$ /$$__  $$ /$$__  $$
        |  $$$$$$       | $$__/| $$  \ $$| $$  \__/| $$$$$$$$ \  $$$$/       | $$__/   | $$  /$$$$$$$| $$  \ $$| $$  \ $$| $$  \__/
         \____  $$      | $$   | $$  | $$| $$      | $$_____/   $$  $$       | $$      | $$ /$$__  $$| $$  | $$| $$  | $$| $$      
         /$$  \ $$      | $$   |  $$$$$$/| $$      |  $$$$$$$ /$$/\  $$      | $$      | $$|  $$$$$$$|  $$$$$$$|  $$$$$$$| $$      
        |  $$$$$$/      |__/    \______/ |__/       \_______/|__/  \__/      |__/      |__/ \_______/ \____  $$ \____  $$|__/      
         \_  $$_/                                                                                     /$$  \ $$ /$$  \ $$          
           \__/                                                                                      |  $$$$$$/|  $$$$$$/          
                                                                                                      \______/  \______/                   
    ______________________________________________________________________________________________________________________________________________
    ______________________________________________________________________________________________________________________________________________                                                 
    """
print(msg)

==> forexflaggr-0.0.5.tar.gz: forexflaggr-0.0.5/forexflaggr/__init__.py <==
from .src.dependencies import (make_subplots, go, px, LinearGAM, lowess, dt, yf, np, warnings)
from .src.pie_chart_recommendation import pie_chart_recommendation
from .src.html_config import Build_HTML_Config
from .src.forex_flaggr import ForexFlaggr
from .src.loess_model import LOESS_Model
from .src.gam_model import GAM_Model

import yaml

# get version from build spec: how to read for package?
# with open("../build_spec.yml", "r") as f:
#     build_spec = yaml.load(f, Loader=yaml.FullLoader)

# __version__         = build_spec['__version__']
# __author__          = build_spec['__author__']
# __email__           = build_spec['__email__']
# __credits__         = build_spec['__credits__']

__version__  = "0.0.5"
__author__   = 'Zach Wolpe'
__credits__  = 'MLXGO'
__email__    = 'zach.wolpe@mlxgo.com'



msg =   """
    ______________________________________________________________________________________________________________________________________________
    ______________________________________________________________________________________________________________________________________________

            /$$          /$$$$$$$$                                            /$$$$$$$$ /$$                                        
          /$$$$$$       | $$_____/                                           | $$_____/| $$                                        
         /$$__  $$      | $$     /$$$$$$   /$$$$$$   /$$$$$$  /$$   /$$      | $$      | $$  /$$$$$$   /$$$$$$   /$$$$$$   /$$$$$$ 
        | $$  \__/      | $$$$$ /$$__  $$ /$$__  $$ /$$__  $$|  $$ /$$/      | $$$$$   | $$ |____  $$ /$$__  $$ /$$__  $$ /$$__  $$
        |  $$$$$$       | $$__/| $$  \ $$| $$  \__/| $$$$$$$$ \  $$$$/       | $$__/   | $$  /$$$$$$$| $$  \ $$| $$  \ $$| $$  \__/
         \____  $$      | $$   | $$  | $$| $$      | $$_____/   $$  $$       | $$      | $$ /$$__  $$| $$  | $$| $$  | $$| $$      
         /$$  \ $$      | $$   |  $$$$$$/| $$      |  $$$$$$$ /$$/\  $$      | $$      | $$|  $$$$$$$|  $$$$$$$|  $$$$$$$| $$      
        |  $$$$$$/      |__/    \______/ |__/       \_______/|__/  \__/      |__/      |__/ \_______/ \____  $$ \____  $$|__/      
         \_  $$_/                                                                                     /$$  \ $$ /$$  \ $$          
           \__/                                                                                      |  $$$$$$/|  $$$$$$/          
                                                                                                      \______/  \______/                   
    ______________________________________________________________________________________________________________________________________________
    ______________________________________________________________________________________________________________________________________________                                                 
    """
print(msg)
